# gera2ld.aioproxy

[![PyPI](https://img.shields.io/pypi/v/gera2ld.aioproxy.svg)](https://pypi.org/project/gera2ld.aioproxy/)

A simple HTTP proxy server implemented with pure Python on top of [aiohttp](https://aiohttp.readthedocs.io/).

## Installation

```sh
$ pip3 install gera2ld.aioproxy
```

## Usage

```sh
$ aioproxy [-b :1086] [-x socks5://127.0.0.1:1080]
```
